/*
 * file CcConfigSpec.java
 *
 *
 * Licensed Materials - Property of IBM 
 * Restricted Materials of IBM  
 * 
 * com.ibm.rational.wvcm.stp.cc.CcConfigSpec
 * 
 * (C) Copyright IBM Corporation 2004, 2008.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */

package com.ibm.rational.wvcm.stp.cc;

import java.util.List;

import javax.wvcm.WvcmException;

/**
 * <p>
 * The configuration specification ("config spec") for a ClearCase view.
 * A view's config spec determines which elements appear in a view,
 * and which version of each element is selected by the view.
 * For snapshot and web views, the config spec also determines which
 * files are loaded in the view.
 * </p>
 * <p> 
 * A ConfigSpec has two sections, one containing element rules
 * and one containing load rules. Methods are provided to manipulate
 * each of these sections.
 * </p>
 * <p>
 * CcView.getConfigSpec returns a ConfigSpec object.
 * ConfigSpec objects can be passed into CcView.doSetConfigSpec
 * to change the configuration specification of a view.
 * </p>
 */
public interface CcConfigSpec
{
    /**
     * Returns the "Element Rules" section (everything except the load rules)
     * of the configuration specification.
     * 
     * @return the element rules as a single newline-separated string
     * Returns empty string if none.
     */
    public String getElementRules();
    
    /**
     * Returns the automatically-generated UCM section of the configuration
     * specification.
     * 
     * @return the UCM-generated element rules.
     * Returns empty string if none (i.e. if not a UCM view.)
     */
    public String getUcmElementRules();
    
    /**
     * Returns the load-rules section of a configuration specification.
     * 
     * @return the load-rules, as a single newline-separated string.
     * Returns empty string if none (i.e. if not a snapshot view or a web view).
     */
    public String getLoadRules();
        
    /**
     * Sets the "Element Rules" (everything except the load rules) section of a ConfigSpec object.
     * Note that the ConfigSpec object needs to be passed into 
     * CcView.doSetConfigSpec in order for the altered config spec
     * to actually be set in a particular view.
     *
     * @param elementRules a newline-separated string representing the new element rules
     */
    public void setElementRules(String elementRules);
    
    /**
     * Sets the load-rules section of a configuration specification.
     * Note that the ConfigSpec object needs to be passed into 
     * CcView.doSetConfigSpec in order for the altered config spec
     * to actually be set in a particular view.
     * 
     * @param loadRules a newline-separated string representing the new load rules
     */
    public void setLoadRules(String loadRules);

    /**
     * @deprecated For internal use only
     */
    public String toXml() throws WvcmException;
    
}